@@ -15,7 +15,7 @@ package WebGUI::Asset;
 =cut
 
 use Carp qw( croak confess );
-use Scalar::Util qw( blessed );
+use Scalar::Util qw( blessed weaken );
 use Clone qw(clone);
 use JSON;
 use HTML::Packer;
@@ -40,6 +40,7 @@ use WebGUI::ProgressBar;
 use WebGUI::Search::Index;
 use WebGUI::TabForm;
 use WebGUI::Utility;
+use WebGUI::PassiveAnalytics::Logging;
 
 =head1 NAME
 
@@ -558,6 +559,62 @@ sub definition {
 }
 
 
+#-------------------------------------------------------------------
+
+=head2 dispatch ( $fragment )
+
+Based on the URL and query parameters in the current request, call internal methods
+like www_view, www_edit, etc.  If no query parameter is present, then it returns the output
+from the www_view method.  If the requested method does not exist in the object, it returns
+the output from the www_view method.
+
+=head3 $fragment
+
+Any leftover part of the requested URL.
+
+=cut
+
+sub dispatch {
+    my ($self, $fragment) = @_;
+    return undef if $fragment;
+    my $session = $self->session;
+    my $state = $self->get('state');
+    ##Only allow interaction with assets in certain states
+    return if $state ne 'published' && $state ne 'archived' && !$session->var->isAdminOn;
+    my $func    = $session->form->param('func') || 'view';
+    my $viewing = $func eq 'view' ? 1 : 0;
+    my $sub     = $self->can('www_'.$func);
+    if (!$sub && $func ne 'view') {
+        $sub     = $self->can('www_view');
+        $viewing = 1;
+    }
+    return undef unless $sub;
+    my $output = eval { $self->$sub(); };
+    if (my $e = Exception::Class->caught('WebGUI::Error::ObjectNotFound::Template')) {
+                                         #WebGUI::Error::ObjectNotFound::Template
+        $session->log->error(sprintf "%s templateId: %s assetId: %s", $e->error, $e->templateId, $e->assetId);
+    }
+    elsif ($@) {
+        my $message = $@;
+        $session->log->warn("Couldn't call method www_".$func." on asset for url: ".$session->url->getRequestedUrl." Root cause: ".$message);
+    }
+    return $output if $output || $viewing;
+    ##No output, try the view method instead
+    $output = eval { $self->www_view };
+    if (my $e = Exception::Class->caught('WebGUI::Error::ObjectNotFound::Template')) {
+        $session->log->error(sprintf "%s templateId: %s assetId: %s", $e->error, $e->templateId, $e->assetId);
+        return "chunked";
+    }
+    elsif ($@) {
+        warn "logged another warn: $@";
+        my $message = $@;
+        $session->log->warn("Couldn't call method www_view on asset for url: ".$session->url->getRequestedUrl." Root cause: ".$@);
+        return "chunked";
+    }
+    return $output;
+}
+
+
 #-------------------------------------------------------------------
 
 =head2 drawExtraHeadTags ( )
@@ -1825,11 +1882,8 @@ no revision date is available it will return undef.
 =cut
 
 sub new {
-    my $class           = shift;
-    my $session         = shift;
-    my $assetId         = shift;
-    my $className       = shift;
-    my $revisionDate    = shift;
+    my ( $class, $session, $assetId, $className, $revisionDate ) = @_;
+    weaken( $session );
 
     unless (defined $assetId) {
         $session->errorHandler->error("Asset constructor new() requires an assetId.");
@@ -1867,18 +1921,19 @@ sub new {
             $session->errorHandler->error("Asset $assetId $class $revisionDate is missing properties. Consult your database tables for corruption. ");
             return undef;
         }
+        # Deserialize
+        foreach my $definition (@{ $class->definition($session) }) {
+            foreach my $property (keys %{ $definition->{properties} }) {
+                if ($definition->{properties}->{$property}->{serialize} && $properties->{$property} ne '') {
+                    $properties->{$property} = JSON->new->canonical->decode($properties->{$property});
+                }
+            }
+        }
         $cache->set($properties,60*60*24);
     }
     if (defined $properties) {
         my $object = { _session=>$session, _properties => $properties };
         bless $object, $class;
-        foreach my $definition (@{ $object->definition($session) }) {
-            foreach my $property (keys %{ $definition->{properties} }) {
-                if ($definition->{properties}->{$property}->{serialize} && $object->{_properties}->{$property} ne '') {
-                    $object->{_properties}->{$property} = JSON->new->canonical->decode($object->{_properties}->{$property});
-                }
-            }
-        }
         return $object;
     }	
     $session->errorHandler->error("Something went wrong trying to instanciate a '$className' with assetId '$assetId', but I don't know what!");
@@ -2201,7 +2256,6 @@ sub packExtraHeadTags {
     return $unpacked if !$unpacked;
     my $packed  = $unpacked;
     HTML::Packer::minify( \$packed, {
-        remove_comments     => 1,
         remove_newlines     => 1,
         do_javascript       => "shrink",
         do_stylesheet       => "minify",
@@ -2607,7 +2661,15 @@ sub update {
 
             # set the property
             if ($propertyDefinition->{serialize}) {
-                $setPairs{$property} = JSON->new->canonical->encode($value);
+                # Only serialize references
+                if ( ref $value ) {
+                    $setPairs{$property} = JSON->new->canonical->encode($value);
+                }
+                # Passing already serialized JSON string
+                elsif ( $value ) {
+                    $setPairs{$property} = $value;
+                    $value = JSON->new->decode( $value ); # for setting in _properties, below
+                }
             }
             else {
                 $setPairs{$property} = $value;
@@ -2742,7 +2804,7 @@ sub www_add {
 		isHidden => $self->get("isHidden"),
 		className=>$class,
 		assetId=>"new",
-		url=>$self->session->form->param("url")
+		url=>scalar($self->session->form->param("url")),
 		);
 	$properties{isHidden} = 1 unless $self->session->config->get("assets/".$class."/isContainer");
 	my $newAsset = WebGUI::Asset->newByPropertyHashRef($self->session,\%properties);
@@ -2780,7 +2842,7 @@ sub www_changeUrl {
 	my $i18n = WebGUI::International->new($self->session, "Asset");
 	my $f = WebGUI::HTMLForm->new($self->session, action=>$self->getUrl);
 	$f->hidden(name=>"func", value=>"changeUrlConfirm");
-	$f->hidden(name=>"proceed", value=>$self->session->form->param("proceed"));
+	$f->hidden(name=>"proceed", value=>scalar($self->session->form->param("proceed")));
 	$f->text(name=>"url", value=>$self->get('url'), label=>$i18n->get("104"), hoverHelp=>$i18n->get('104 description'));
 	$f->yesNo(name=>"confirm", value=>0, label=>$i18n->get("confirm change"), hoverHelp=>$i18n->get("confirm change url message"), subtext=>'<br />'.$i18n->get("confirm change url message"));
 	$f->submit;
@@ -2926,6 +2988,10 @@ sub www_editSave {
         $session->asset($object->getParent);
         return $session->asset->www_view;
     }
+    elsif ($proceed eq "editParent") {
+        $session->asset($object->getParent);
+        return $session->asset->www_edit;
+    }    
     elsif ($proceed eq "goBackToPage" && $session->form->process('returnUrl')) {
         $session->http->setRedirect($session->form->process("returnUrl"));
         return undef;
