@@ -59,6 +59,7 @@ sub addRevision {
     if ($newSelf->get("storageId") && $newSelf->get("storageId") eq $self->get('storageId')) {
         my $newStorage = $self->getStorageClass->get($self->session,$self->get("storageId"))->copy;
         $newSelf->update({storageId => $newStorage->getId});
+        $newSelf->applyConstraints;
     }
 
     return $newSelf;
@@ -379,6 +380,7 @@ sub indexContent {
 	my $self = shift;
 	my $indexer = $self->SUPER::indexContent;
 	$indexer->addFile($self->getStorageLocation->getPath($self->get("filename")));
+	return $indexer;
 }
 
 
@@ -581,7 +583,7 @@ sub update {
 		$self->setStorageLocation;
 	}
 	if ($self->get("ownerUserId") ne $before{owner} || $self->get("groupIdEdit") ne $before{edit} || $self->get("groupIdView") ne $before{view}) {
-		$self->getStorageLocation->setPrivileges($self->get("ownerUserId"),$self->get("groupIdView"),$self->get("groupIdEdit"));
+        $self->setPrivileges;
 	}
 }
 
