@@ -27,13 +27,19 @@ use base qw(WebGUI::AssetAspect::RssFeed WebGUI::Asset::Wobject);
 #-------------------------------------------------------------------
 sub _computePostCount {
 	my $self = shift;
-	return scalar @{$self->getLineage(['descendants'], {includeOnlyClasses => ['WebGUI::Asset::Post']})};
+	return $self->getDescendantCount({
+            includeOnlyClasses => ['WebGUI::Asset::Post'],
+            statusToInclude     => ['approved'],
+        });
 }
 
 #-------------------------------------------------------------------
 sub _computeThreadCount {
 	my $self = shift;
-	return scalar @{$self->getLineage(['children'], {includeOnlyClasses => ['WebGUI::Asset::Post::Thread']})};
+	return $self->getChildCount({
+            includeOnlyClasses => ['WebGUI::Asset::Post::Thread'],
+            statusToInclude => ['approved'],
+        });
 }
 
 #-------------------------------------------------------------------
@@ -391,25 +397,6 @@ sub canStartThread {
 }
 
 
-#-------------------------------------------------------------------
-
-=head2 canView ( [ $userId ] )
-
-Extends the base method to also allow users who canPost to the CS.
-
-=head3 $userId
-
-A userId to check for edit permissions. If $userId is false, then it checks
-the current session user.
-
-=cut
-
-sub canView {
-	my $self = shift;
-        my $userId  = shift     || $self->session->user->userId;
-	return $self->next::method( $userId ) || $self->canPost( $userId );
-}
-
 #-------------------------------------------------------------------
 
 =head2 commit 
@@ -569,6 +556,7 @@ sub definition {
 			tab=>'mail',
 			label=>$i18n->get("mail account"),
 			hoverHelp=>$i18n->get("mail account help"),
+            extras => 'autocomplete="off"',
 			},
 		mailPassword=>{
 			fieldType=>"password",
@@ -576,6 +564,7 @@ sub definition {
 			tab=>'mail',
 			label=>$i18n->get("mail password"),
 			hoverHelp=>$i18n->get("mail password help"),
+            extras => 'autocomplete="off"',
 			},
 		mailAddress=>{
 			fieldType=>"email",
@@ -895,6 +884,14 @@ sub definition {
             hoverHelp=>$i18n->get('post received template hoverHelp'),
             defaultValue=>'default_post_received1',
         },
+        unsubscribeTemplateId =>{
+            fieldType=>'template',
+            namespace=>'Collaboration/Unsubscribe',
+            tab=>'display',
+            label=>$i18n->get('unsubscribe template'),
+            hoverHelp=>$i18n->get('unsubscribe template hoverHelp'),
+            defaultValue=>'default_CS_unsubscribe',
+        },
         );
 
         push(@{$definition}, {
@@ -1379,11 +1376,19 @@ sub processPropertiesFromFormPost {
 		$self->createSubscriptionGroup;
 	}
         if ($updatePrivs) {
-                foreach my $descendant (@{$self->getLineage(["descendants"],{returnObjects=>1})}) {
-                        $descendant->update({
-                                groupIdView=>$self->get("groupIdView"),
-                                groupIdEdit=>$self->get("groupIdEdit")
-                                });
+                my $descendantIter = $self->getLineageIterator(['descendants']);
+                while ( 1 ) {
+                    my $descendant;
+                    eval { $descendant = $descendantIter->() };
+                    if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+                        $self->session->log->error($x->full_message);
+                        next;
+                    }
+                    last unless $descendant;
+                    $descendant->update({
+                            groupIdView=>$self->get("groupIdView"),
+                            groupIdEdit=>$self->get("groupIdEdit")
+                            });
                 }
         }
 	$self->session->scratch->delete($self->getId."_sortBy");
@@ -1542,18 +1547,22 @@ sub subscribe {
 
 #-------------------------------------------------------------------
 
-=head2 unsubscribe (  )
+=head2 unsubscribe ( [$user] )
 
 Unsubscribes a user from this collaboration system
 
+=head3 $user
+
+An optional user object to unsubscribe.  If the object isn't passed, then it uses the session user.
+
 =cut
 
 sub unsubscribe {
-	my $self = shift;
-	my $group = WebGUI::Group->new($self->session,$self->get("subscriptionGroupId"));
-	return
-        unless $group;
-    $group->deleteUsers([$self->session->user->userId],[$self->get("subscriptionGroupId")]);
+    my $self  = shift;
+    my $user  = shift || $self->session->user;
+    my $group = WebGUI::Group->new($self->session,$self->get("subscriptionGroupId"));
+    return unless $group;
+    $group->deleteUsers([$user->userId]);
 }
 
 
@@ -1598,7 +1607,7 @@ sub www_edit {
     return $self->session->privilege->locked() unless $self->canEditIfLocked;
     my $i18n = WebGUI::International->new($self->session, 'Asset_Collaboration');
     $self->getAdminConsole->addConfirmedSubmenuItem($self->getUrl('func=unarchiveAll'),$i18n->get("unarchive all"),$i18n->get("unarchive confirm"));
-    return $self->getAdminConsole->render($self->getEditForm->print,$i18n->get("assetName"));
+    return $self->getAdminConsole->render($self->getEditForm->print,$self->getName);
 }
 
 #-------------------------------------------------------------------
@@ -1674,40 +1683,85 @@ sub www_unarchiveAll {
     my $pb      = WebGUI::ProgressBar->new($session);
     my $i18n     = WebGUI::International->new($session, 'Asset_Collaboration');
     $pb->start($i18n->get('unarchive all'), $self->getUrl('func=edit'));
-    my $threadIds = $self->getLineage(['children'],{
+    my $threadIter = $self->getLineageIterator(['children'],{
         includeOnlyClasses      => [ 'WebGUI::Asset::Post::Thread' ],
         statusToInclude         => [ 'archived' ],
     } );
-    ASSET: foreach my $threadId (@$threadIds) {
-        my $thread = WebGUI::Asset->newPending($session, $threadId);
-        if (!$thread || !$thread->canEdit) {
-            next ASSET;
+    ASSET: while ( 1 ) {
+        my $thread;
+        eval { $thread = $threadIter->() };
+        if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+            $session->log->error($x->full_message);
+            next;
+        }
+        last unless $thread;
+        if ($thread->canEdit) {
+            $thread->unarchive;
         }
-        $thread->unarchive;
     }
     return $pb->finish( $self->getUrl('func=edit') );
 }
 
 #-------------------------------------------------------------------
 
-=head2 www_unsubscribe (  )
+=head2 www_unsubscribe ( [$message] )
 
 The web method to unsubscribe from a collaboration.
 
+=head3 $message
+
+An error message to display to the user.
+
 =cut
 
 sub www_unsubscribe {
-    my $self = shift;
+    my $self    = shift;
+    my $message = shift;
     if($self->canSubscribe){
         $self->unsubscribe;
         return $self->www_view;
-    }else{
-        return $self->session->privilege->noAccess;
+    }
+    else {
+        my $session = $self->session;
+        my $i18n    = WebGUI::International->new($session, 'Asset_Collaboration');
+        my $var     = $self->get();
+        $var->{title}       = $self->getTitle;
+        $var->{url}         = $self->getUrl;
+        $var->{formHeader}  = WebGUI::Form::formHeader($session)
+                            . WebGUI::Form::hidden($session, { name => 'func', value => 'unsubscribeConfirm', }, ),
+        $var->{formFooter}  = WebGUI::Form::formFooter($session),
+        $var->{formSubmit}  = WebGUI::Form::submit($session, { value => $i18n->get('unsubscribe'), }),
+        $var->{formEmail}   = WebGUI::Form::email($session, { name => 'userEmail', value => $session->form->process('userEmail'), }),
+        $var->{formMessage} = $message;
+        return $self->processStyle($self->processTemplate($var, $self->get("unsubscribeTemplateId")));
     } 
 }
 
 #-------------------------------------------------------------------
 
+=head2 www_unsubscribeConfirm (  )
+
+Process the unsubscribe form.
+
+=cut
+
+sub www_unsubscribeConfirm {
+    my $self    = shift;
+    my $session = $self->session;
+    return $self->www_view unless $session->form->validToken;
+    my $email   = $session->form->process('userEmail', 'email');
+    return $self->www_view unless $email;
+    my $user = WebGUI::User->newByEmail($session, $email);
+    my $i18n = WebGUI::International->new($session, 'Asset_Collaboration');
+    if (! $user) {
+        return $self->www_unsubscribe($i18n->get('no user email error message'));
+    }
+    $self->unsubscribe($user);
+    return $self->www_unsubscribe($i18n->get('You have been unsubscribed'));
+}
+
+#-------------------------------------------------------------------
+
 =head2 www_view 
 
 Extend the base method to handle the visitor cache timeout.
