@@ -22,6 +22,9 @@ use WebGUI::International;
 use WebGUI::Utility;
 use HTML::Parser;
 use URI::Escape;
+use WebGUI::Form;
+use WebGUI::Search;
+use Clone qw/clone/;
 
 #-------------------------------------------------------------------
 
@@ -43,12 +46,29 @@ sub appendFeaturedPageVars {
 
 #-------------------------------------------------------------------
 
+=head2 appendKeywordPageVars ( var )
+
+Append the template variables to C<var> for keyword (category) pages.
+
+=cut
+
+sub appendKeywordPageVars {
+    my ( $self, $var ) = @_;
+    my $topKeywords    = $self->getTopLevelKeywordsList;
+    my $keywordHierarchy  = $self->getKeywordHierarchy( $topKeywords, );
+    $var->{keywords_loop} = $self->getKeywordVariables( $keywordHierarchy );
+    return $var;
+}
+
+#-------------------------------------------------------------------
+
+
 =head2 appendMostPopular ($var, [ $limit ])
 
 =head3 $var
 
 A hash reference of template variables.  An array reference containing the most popular wiki pages
-in order of popularity.
+in order of popularity will be appended to it.
 
 =head3 $limit
 
@@ -60,15 +80,19 @@ sub appendMostPopular {
     my $self  = shift;
     my $var   = shift;
     my $limit = shift || $self->get("mostPopularCount");
-	foreach my $asset (@{$self->getLineage(["children"],{returnObjects=>1, limit=>$limit, includeOnlyClasses=>["WebGUI::Asset::WikiPage"], joinClass => 'WebGUI::Asset::WikiPage', orderByClause => 'WikiPage.views DESC'})}) { 
-		if (defined $asset) {
+    my $assetIter = $self->getLineageIterator(["children"],{limit=>$limit, includeOnlyClasses=>["WebGUI::Asset::WikiPage"], joinClass => 'WebGUI::Asset::WikiPage', orderByClause => 'WikiPage.views DESC'});
+    while ( 1 ) {
+        my $asset;
+        eval { $asset = $assetIter->() };
+        if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+            $self->session->log->error($x->full_message);
+            next;
+        }
+        last unless $asset;
 			push(@{$var->{mostPopular}}, {
 				title=>$asset->getTitle,
 				url=>$asset->getUrl,
 				});
-		} else {
-			$self->session->errorHandler->error("Couldn't instanciate wikipage for master ".$self->getId);
-		}
 	}
 }
 
@@ -425,6 +449,13 @@ sub definition {
                         label=>$i18n->get('filter code'),
                         hoverHelp=>$i18n->get('filter code description'),
                         },
+                topLevelKeywords =>{
+                        fieldType    => "keywords",
+                        defaultValue => '',
+                        tab          => 'properties',
+                        label        => $i18n->get('top level keywords'),
+                        hoverHelp    => $i18n->get('top level keywords description'),
+                },
 		);
 
 	push @$definition,
@@ -442,6 +473,23 @@ sub definition {
 
 #-------------------------------------------------------------------
 
+=head2 deleteSubKeywords ( $keyword )
+
+Delete all keywords that are associated with a particular keyword for this wiki.
+
+=head3 $keyword
+
+The main keyword to key off of.
+
+=cut
+
+sub deleteSubKeywords {
+    my ( $self, $keyword ) = @_;
+    return $self->session->db->write('delete from WikiMasterKeywords where assetId=? and keyword=?', [$self->getId, $keyword]);
+}
+
+#-------------------------------------------------------------------
+
 =head2 getFeaturedPageIds ( )
 
 Get the asset IDs of the pages that are marked as Featured.
@@ -461,6 +509,130 @@ sub getFeaturedPageIds {
 
 #-------------------------------------------------------------------
 
+=head2 getKeywordHierarchy ( $keywords, $seen )
+
+Starting with the top level keywords, return the hierarchy of keywords as a recursive arrayref of hashrefs.
+The traversal is left-most, depth first.
+
+The hierarchy data structure that looks like this:
+
+    [
+        {
+            keyword => 'keyword', # same as the keyword, since this is a keyword (category) page
+            url     => 'url',     # url from the keyword page, via getUrl so it contains the gateway URL
+            children => [         # Array reference of sub-categories referenced by this category
+                {                 # If there are no children, this key/value pair will not be present
+                    ...
+                }
+            ],
+            descendants => 25,    # The total number of wiki pages that this keyword, and any other sub-keywords
+                                  # of this keyword, refer to.
+        }
+    ]
+
+=head3 $keywords
+
+An array reference of keywords.  If this is blank, then it will use the top level keywords from
+itself as a default.
+
+=head3 $seen
+
+A hash reference that keeps track of which keywords have already been seen.  This prevents
+infinite loops from happening during the traversal.
+
+=cut
+
+sub getKeywordHierarchy {
+    my ( $self, $keywords, $seen ) = @_;
+    my $session     = $self->session;
+    my $hierarchy   = [];
+    $keywords     ||= $self->getTopLevelKeywordsList;
+    $seen         ||= {};
+    my $assetKeyword = WebGUI::Keyword->new($session);
+    KEYWORD: foreach my $keyword (sort @{ $keywords }) {
+        my $datum = {
+            title       => $keyword,  ##Note, same as keyword
+            url         => $self->getUrl('func=byKeyword;keyword='.$keyword),
+            descendants => scalar @{ $assetKeyword->getMatchingAssets( {
+                                        startAsset => $self,
+                                        keyword    => $keyword,
+                                        sortOrder  => 'Alphabetically',
+                                  }) },
+        };
+        ##Prevent recursion if seen again
+        if (! $seen->{$keyword}++) {
+            ##Replace this with a call to getSubKeywords.
+            my $children =  $self->getKeywordHierarchy($self->getSubKeywords($keyword), $seen, );
+            if (@{ $children } ) {
+                foreach my $child (@{ $children }) {
+                    $datum->{descendants} += $child->{descendants};
+                }
+                $datum->{children} = $children;
+            }
+        }
+        push @{ $hierarchy }, $datum;
+    }
+    return $hierarchy;
+}
+
+#-------------------------------------------------------------------
+
+=head2 getSubKeywords ( $keyword )
+
+Return all keywords that are associated with a particular keyword for this wiki.
+
+=head3 $keyword
+
+The main keyword to key off of.
+
+=cut
+
+sub getSubKeywords {
+    my ( $self, $keyword ) = @_;
+    return $self->session->db->buildArrayRef(
+        'select subKeyword from WikiMasterKeywords where assetId=? and keyword=?',
+        [$self->getId, $keyword]
+    );
+}
+
+#-------------------------------------------------------------------
+
+=head2 getKeywordVariables ( $hierarchy, $level )
+
+Take a data structure representing a hierarchy of keywords, and append template variables
+to them similar to a Navigation so you can build useful things with them.
+
+=head3 $hierarchy
+
+A data structure similar to that produced by getKeywordHierarchy
+
+=head3 $level
+
+The current level in any part of the hierarchy.
+
+=cut
+
+sub getKeywordVariables {
+    my ( $self, $hierarchy, $level ) = @_;
+    $level ||= 0;
+    my $variables = [];
+
+    KEYWORD: foreach my $member (@{ $hierarchy }) {
+        my $varBlock             = clone $member;
+        $varBlock->{level}       = $level;
+        $varBlock->{isTopLevel}  = $level == 0;
+        $varBlock->{indent_loop} = [ map { { indent => $_ } } 1..$level ];
+        delete $varBlock->{children};
+        push @{$variables}, $varBlock;
+        if ( exists $member->{children} ) {
+            push @{$variables}, @{ $self->getKeywordVariables($member->{children}, $level+1) };
+        }
+    }
+    return $variables;
+}
+
+#-------------------------------------------------------------------
+
 =head2 getRssFeedItems ()
 
 Returns an array reference of hash references. Each hash reference has a title,
@@ -520,6 +692,19 @@ sub getTemplateVars {
     return $var;
 }
 
+#----------------------------------------------------------------------------
+
+=head2 getTopLevelKeywordsList ( )
+
+Return the top level keywords as an array reference.
+
+=cut
+
+sub getTopLevelKeywordsList {
+    my ( $self ) = @_;
+    return WebGUI::Keyword::string2list($self->get('topLevelKeywords'));
+}
+
 #-------------------------------------------------------------------
 
 =head2 prepareView 
@@ -558,7 +743,16 @@ sub processPropertiesFromFormPost {
 	     or ($self->session->form->process('groupIdEdit') ne $self->get('groupIdEdit')));
 	my $ret = $self->next::method(@_);
 	if ($groupsChanged) {
-		foreach my $child (@{$self->getLineage(['children'], {returnObjects => 1})}) {
+                # XXX Should this do descendants for WikiPage attachments?
+                my $childIter = $self->getLineageIterator(['children']);
+                while ( 1 ) {
+                    my $child;
+                    eval { $child = $childIter->() };
+                    if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+                        $self->session->log->error($x->full_message);
+                        next;
+                    }
+                    last unless $child;
 			$child->update({ groupIdView => $self->get('groupIdView'),
 					 groupIdEdit => $self->get('groupIdEdit') });
 		}
@@ -568,6 +762,48 @@ sub processPropertiesFromFormPost {
 
 #-------------------------------------------------------------------
 
+=head2 purge 
+
+Extend the master method to delete all keyword entries.
+
+=cut
+
+sub purge {
+	my $self = shift;
+    $self->session->db->write('delete from WikiMasterKeywords where assetId=?',[$self->getId]);
+    return $self->SUPER::purge;
+}
+
+#-------------------------------------------------------------------
+
+=head2 setSubKeywords ( $keyword, @keywords )
+
+Store the set of keywords for this WikiMaster in the db.  Returns true.
+
+=head3 $keyword
+
+The keyword that gets the new keywords.
+
+=head3 @keywords
+
+The new set of keywords.
+
+=cut
+
+sub setSubKeywords {
+    my ( $self, $keyword, @subKeywords ) = @_;
+    $self->deleteSubKeywords($keyword);
+    my $stuffIt = $self->session->db->prepare('insert into WikiMasterKeywords (assetId, keyword, subKeyword) values (?,?,?)');
+    KEYWORD: foreach my $subKeyword (@subKeywords) {
+        next unless $keyword;
+        $stuffIt->execute([$self->getId, $keyword, $subKeyword]);
+    }
+    $stuffIt->finish;
+    return 1;
+}
+
+#-------------------------------------------------------------------
+
 =head2 shouldSkipNotification ( )
 
 WikiMasters do not send notification
@@ -610,6 +846,7 @@ sub view {
 	$self->appendSearchBoxVars($var);
 	$self->appendRecentChanges($var, $self->get('recentChangesCountFront'));
 	$self->appendMostPopular($var, $self->get('mostPopularCountFront'));
+	$self->appendKeywordPageVars($var);
 	return $self->processTemplate($var, undef, $template);
 }
 
@@ -623,29 +860,54 @@ Return search results that match the keyword from the form variable C<keyword>.
 =cut
 
 sub www_byKeyword {
-    my $self = shift;
-    my $keyword = $self->session->form->process("keyword");
-    my @pages = ();
-    my $p = WebGUI::Keyword->new($self->session)->getMatchingAssets({
+    my $self    = shift;
+    my $session = $self->session;
+    my $keyword = $session->form->process("keyword");
+
+    my $p = WebGUI::Keyword->new($session)->getMatchingAssets({
         startAsset      => $self,
         keyword         => $keyword,   
         usePaginator    => 1,
-        });
+    });
     $p->setBaseUrl($self->getUrl("func=byKeyword;keyword=".$keyword));
+
+    my @pages  = ();
     foreach my $assetData (@{$p->getPageData}) {
-        my $asset = WebGUI::Asset->newByDynamicClass($self->session, $assetData->{assetId});
+        my $asset = WebGUI::Asset->newByDynamicClass($session, $assetData->{assetId});
         next unless defined $asset;
         push(@pages, {
-            title   => $asset->getTitle,
-            url     => $asset->getUrl,
+            title    => $asset->getTitle,
+            url      => $asset->getUrl,
+            synopsis => $asset->get('synopsis'),
             });
     }
     @pages = sort { lc($a->{title}) cmp lc($b->{title}) } @pages;
     my $var = {
-        keyword => $keyword,
-        pagesLoop => \@pages,
-        };
+        keyword          => $keyword,
+        pagesLoop        => \@pages,
+        canAdminister    => $self->canAdminister,
+		recentChangesUrl => $self->getUrl("func=recentChanges"),
+		mostPopularUrl   => $self->getUrl("func=mostPopular"),
+		wikiHomeUrl      => $self->getUrl,
+    };
     $p->appendTemplateVars($var);
+
+    my $subKeywords       = $self->getSubKeywords($keyword);
+    my $keywordHierarchy  = $self->getKeywordHierarchy($subKeywords);
+    $var->{keywords_loop} = $self->getKeywordVariables($keywordHierarchy);
+
+    if ($var->{canAdminister}) {
+        $var->{formHeader}  = WebGUI::Form::formHeader($session, {action => $self->getUrl})
+                            . WebGUI::Form::hidden($session, { name => 'func',    value => 'subKeywordSave',})
+                            . WebGUI::Form::hidden($session, { name => 'keyword', value => $keyword,});
+        my $subKeywords = join ', ', @{ $self->getSubKeywords($keyword) };
+        $var->{keywordForm} = WebGUI::Form::keywords($session, {
+                                                       name  => 'subKeywords',
+                                                       value => $session->form->get('subKeywords') || $subKeywords,
+                                                       });
+        $var->{submitForm} = WebGUI::Form::submit($session, {});
+        $var->{formFooter} = WebGUI::Form::formFooter($session);
+    }
 	return $self->processStyle($self->processTemplate($var, $self->get('byKeywordTemplateId')));
 }
 
@@ -724,7 +986,7 @@ sub www_search {
 		mostPopularUrl=>$self->getUrl("func=mostPopular"),
 		mostPopularLabel=>$i18n->get("mostPopularLabel"),
 		wikiHomeUrl=>$self->getUrl,
-		addPageUrl=>$self->getUrl("func=add;class=WebGUI::Asset::WikiPage;title=".$queryString),
+		addPageUrl=>$self->getUrl("func=add;class=WebGUI::Asset::WikiPage;title=".$self->session->url->escape($queryString)),
 		};
 	$self->appendSearchBoxVars($var, $queryString);
 	if (length $queryString) {
@@ -745,4 +1007,24 @@ sub www_search {
 	return $self->processStyle($self->processTemplate($var, $self->get('searchTemplateId')));
 }
 
+#-------------------------------------------------------------------
+
+=head2 www_subKeywordSave 
+
+Process the form from www_byKeyword and update the subkeywords for a keyword in this wiki.
+
+=cut
+
+sub www_subKeywordSave {
+	my $self = shift;
+    my $form = $self->session->form;
+
+    my $subKeywords = $form->process('subKeywords', 'keywords');
+    my $keyword     = $form->process('keyword');
+    my @subKeywords = @{ WebGUI::Keyword::string2list($subKeywords) };
+    $self->setSubKeywords($keyword, @subKeywords);
+
+	return $self->www_byKeyword;
+}
+
 1;
