@@ -67,7 +67,15 @@ sub cut {
 	$session->db->write("update asset set state='clipboard', stateChangedBy=?, stateChanged=? where assetId=?", [$session->user->userId, time(), $self->getId]);
 	$session->db->commit;
 	$self->{_properties}{state} = "clipboard";
-    foreach my $asset ($self, @{$self->getLineage(['descendants'], {returnObjects => 1})}) {
+    my $assetIter = $self->getLineageIterator(['descendants']);
+    while ( 1 ) {
+        my $asset;
+        eval { $asset = $assetIter->() };
+        if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+            $session->log->error($x->full_message);
+            next;
+        }
+        last unless $asset;
         $asset->purgeCache;
         $asset->updateHistory('cut');
     }
@@ -173,6 +181,7 @@ sub getAssetsInClipboard {
        {
            statesToInclude => ["clipboard"],
            returnObjects   => 1,
+           statusToInclude => [qw/approved pending archived/],
            whereClause     => $limit,
        }
     );
@@ -204,7 +213,8 @@ sub paste {
     return 0 unless ($pastedAsset->canPaste());  ##Allow pasted assets to have a say about pasting.
 
     # Don't allow a shortcut to create an endless loop
-	return 0 if ($pastedAsset->get("className") eq "WebGUI::Asset::Shortcut" && $pastedAsset->get("shortcutToAssetId") eq $self->getId);
+    ##Do not paste a shortcut immediately below the original asset
+    return 0 if $pastedAsset->isa('WebGUI::Asset::Shortcut') && $pastedAsset->get("shortcutToAssetId") eq $self->getId;
     my $i18n=WebGUI::International->new($session, 'Asset');
     $outputSub->(sprintf $i18n->get('pasting %s'), $pastedAsset->getTitle) if defined $outputSub;
 	if ($self->getId eq $pastedAsset->get("parentId") || $pastedAsset->setParent($self)) {
@@ -212,11 +222,18 @@ sub paste {
 		$pastedAsset->updateHistory("pasted to parent ".$self->getId);
         
         # Update lineage in search index.
-        my $updateAssets = $pastedAsset->getLineage(['self', 'descendants'], {returnObjects => 1});
+        my $assetIter = $pastedAsset->getLineageIterator(['self', 'descendants']);
+        while ( 1 ) {
+            my $asset;
+            eval { $asset = $assetIter->() };
+            if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+                $session->log->error($x->full_message);
+                next;
+            }
+            last unless $asset;
  
-        foreach (@{$updateAssets}) {
             $outputSub->(sprintf $i18n->get('indexing %s'), $pastedAsset->getTitle) if defined $outputSub;
-            $_->indexContent();
+            $asset->indexContent();
         }
 
 		return 1;
@@ -229,36 +246,98 @@ sub paste {
 
 =head2 www_copy ( )
 
-Duplicates self, cuts duplicate, returns self->getContainer->www_view if canEdit. Otherwise returns an AdminConsole rendered as insufficient privilege.
+Duplicates self, cuts duplicate, returns self->getContainer->www_view if
+canEdit. Otherwise returns an AdminConsole rendered as insufficient privilege.
+If with children/descendants is selected, a progress bar will be rendered.
 
 =cut
 
 sub www_copy {
-    my $self = shift;
-    return $self->session->privilege->insufficient
-        unless $self->canEdit;
+    my $self    = shift;
+    my $session = $self->session;
+    return $session->privilege->insufficient unless $self->canEdit;
 
-
-    # with: 'children' || 'descendants' || ''
-    my $with = $self->session->form->get('with') || '';
-    my $newAsset;
-    if ($with) {
-        my $childrenOnly = $with eq 'children';
-        $newAsset = $self->duplicateBranch($childrenOnly);
+    my $with = $session->form->get('with');
+    if ($with eq 'children') {
+        $self->_wwwCopyChildren;
+    }
+    elsif ($with eq 'descendants') {
+        $self->_wwwCopyDescendants;
     }
     else {
-        $newAsset = $self->duplicate({skipAutoCommitWorkflows => 1});
+        $self->_wwwCopySingle;
     }
-    my $i18n = WebGUI::International->new($self->session, 'Asset');
-    $newAsset->update({ title=>sprintf("%s (%s)",$self->getTitle,$i18n->get('copy'))});
+}
+
+#-------------------------------------------------------------------
+sub _wwwCopyChildren { shift->_wwwCopyProgress(1) }
+
+#-------------------------------------------------------------------
+sub _wwwCopyDescendants { shift->_wwwCopyProgress(0) }
+
+#-------------------------------------------------------------------
+sub _wwwCopyFinish {
+    my ($self, $newAsset) = @_;
+    my $session = $self->session;
+    my $i18n    = WebGUI::International->new($session, 'Asset');
+    my $title   = sprintf("%s (%s)", $self->getTitle, $i18n->get('copy'));
+    $newAsset->update({ title => $title });
     $newAsset->cut;
-    if (WebGUI::VersionTag->autoCommitWorkingIfEnabled($self->session, {
-        allowComments   => 1,
-        returnUrl       => $self->getUrl,
-    }) eq 'redirect') {
-        return undef;
-    };
-    return $self->session->asset($self->getContainer)->www_view;
+    my $result = WebGUI::VersionTag->autoCommitWorkingIfEnabled(
+        $session, {
+            allowComments => 1,
+            returnUrl     => $self->getUrl,
+        }
+    );
+    my $redirect = $result eq 'redirect';
+    $session->asset($self->getContainer) unless $redirect;
+    return $redirect;
+}
+
+#-------------------------------------------------------------------
+sub _wwwCopyProgress {
+    my ($self, $childrenOnly) = @_;
+    my $session = $self->session;
+    my $i18n    = WebGUI::International->new($session, 'Asset');
+
+    # This could potentially time out, so we'll render a progress bar.
+    my $pb = WebGUI::ProgressBar->new($session);
+    my @stack;
+
+    return $pb->run(
+        title => $i18n->get('Copy Assets'),
+        icon  => $session->url->extras('adminConsole/assets.gif'),
+        code  => sub {
+            my $bar = shift;
+            my $newAsset = $self->duplicateBranch($childrenOnly);
+            $bar->update($i18n->get('cut'));
+            my $redirect = $self->_wwwCopyFinish($newAsset);
+            return $redirect ? $self->getUrl : $self->getContainer->getUrl;
+        },
+        wrap  => {
+            'WebGUI::Asset::duplicateBranch' => sub {
+                my ($bar, $original, $asset, @args) = @_;
+                push(@stack, $asset->getTitle);
+                my $ret = $asset->$original(@args);
+                pop(@stack);
+                return $ret;
+            },
+            'WebGUI::Asset::duplicate' => sub {
+                my ($bar, $original, $asset, @args) = @_;
+                my $name = join '/', @stack, $asset->getTitle;
+                $bar->update($name);
+                return $asset->$original(@args);
+            },
+        }
+    );
+}
+
+#-------------------------------------------------------------------
+sub _wwwCopySingle {
+    my $self = shift;
+    my $newAsset = $self->duplicate({skipAutoCommitWorkflows => 1});
+    my $redirect = $self->_wwwCopyFinish($newAsset);
+    return $redirect ? undef : $self->getContainer->www_view;
 }
 
 #-------------------------------------------------------------------
