@@ -57,39 +57,20 @@ sub getAssetsInTrash {
 	my $self = shift;
 	my $limitToUser = shift;
 	my $userId = shift || $self->session->user->userId;
-	my @assets;
 	my $limit;
 	if ($limitToUser) {
-		$limit = "and asset.stateChangedBy=".$self->session->db->quote($userId);
+		$limit = "asset.stateChangedBy=".$self->session->db->quote($userId);
 	}
-	my $sth = $self->session->db->read("
-                select 
-                        asset.assetId, 
-                        assetData.revisionDate,
-                        asset.className
-                from 
-                        asset                 
-                left join 
-                        assetData on asset.assetId=assetData.assetId 
-                where 
-                        asset.state='trash'
-                        and assetData.revisionDate=(SELECT max(revisionDate) from assetData where assetData.assetId=asset.assetId)
-                        $limit
-		group by
-			assetData.assetId
-                order by 
-                        assetData.title desc
-                        ");
-        while (my ($id, $date, $class) = $sth->array) {
-		my $asset = WebGUI::Asset->new($self->session,$id,$class,$date);
-                if ($asset){
-                        push(@assets, $asset);
-                }else{
-                        $self->session->errorHandler->error("AssetTrash::getAssetsInTrash - failed to instanciate asset with assetId $id, className $class, and revisionDate $date");
-                }
-        }
-	$sth->finish;
-	return \@assets;
+    my $root = WebGUI::Asset->getRoot($self->session);
+    return $root->getLineage(
+       ["descendants", ],
+       {
+           statesToInclude => ["trash"],
+           statusToInclude => [qw/approved pending archived/],
+           returnObjects   => 1,
+           whereClause     => $limit,
+       }
+    );
 }
 
 #----------------------------------------------------------------------------
@@ -141,24 +122,23 @@ sub purge {
     }
 
     # assassinate the offspring
-	my $kids = $self->getLineage(["children"],{
-        returnObjects   => 1,
+	my $childIter = $self->getLineageIterator(["children"],{
         statesToInclude => [qw(published clipboard clipboard-limbo trash trash-limbo)],
         statusToInclude => [qw(approved archived pending)],
     });
-	foreach my $kid (@{$kids}) {
-		# Technically get lineage should never return an undefined object from getLineage when called like this, but it did so this saves the world from destruction.
-        if (defined $kid) {
-            unless ($kid->purge) {
+        while ( 1 ) {
+            my $child;
+            eval { $child = $childIter->() };
+            if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+                $session->log->error($x->full_message);
+                next;
+            }
+            last unless $child;
+            unless ($child->purge) {
                 $session->errorHandler->security("delete one of (".$self->getId.")'s children which is a system protected page");
                 $outputSub->(sprintf $i18n->get('Trying to delete system page %s.  Aborting'), $self->getTitle);
                 return 0;
             }
-        }
-        else {
-            $outputSub->($i18n->get('Undefined child'));
-			$session->errorHandler->error("getLineage returned an undefined object in the AssetTrash->purge method.  Unable to purge asset.");
-        }
 	}
 
     # Delete shortcuts to this asset
@@ -266,7 +246,15 @@ sub trash {
         return undef;
     }
 
-    foreach my $asset ($self, @{$self->getLineage(['descendants'], {returnObjects => 1})}) {
+    my $assetIter = $self->getLineageIterator(['self','descendants']);
+    while ( 1 ) {
+        my $asset;
+        eval { $asset = $assetIter->() };
+        if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+            $session->log->error($x->full_message);
+            next;
+        }
+        last unless $asset;
         $outputSub->($i18n->get('Clearing search index'));
         my $index = WebGUI::Search::Index->new($asset);
         $index->delete;
@@ -310,11 +298,16 @@ sub _invokeWorkflowOnExportedFiles {
     if ($workflowId) {
         my ($lastExportedAs) = $self->get("lastExportedAs");
         my $wfInstance = WebGUI::Workflow::Instance->create($self->session, { workflowId => $workflowId });
-        $wfInstance->setScratch(
-            WebGUI::Workflow::Activity::DeleteExportedFiles::DELETE_FILES_SCRATCH() =>
-            Storable::freeze([ defined($lastExportedAs) ? ($lastExportedAs) : () ])
-        );
-        $wfInstance->start(1);
+        if ($wfInstance) {
+            $wfInstance->setScratch(
+                WebGUI::Workflow::Activity::DeleteExportedFiles::DELETE_FILES_SCRATCH() =>
+                Storable::freeze([ defined($lastExportedAs) ? ($lastExportedAs) : () ])
+            );
+            $wfInstance->start(1);
+        }
+        else {
+            $self->session->log->warn('The Purge Workflow from the settings has been deleted and cannot be run.');
+        }
     }
 }
 
