@@ -22,6 +22,7 @@ use WebGUI::Storage;
 use WebGUI::User;
 use WebGUI::Utility;
 use WebGUI::Form::Captcha;
+use WebGUI::Macro;
 use Encode ();
 
 our @ISA = qw(WebGUI::Auth);
@@ -165,7 +166,7 @@ sub createAccount {
     unless($setting->get('webguiUseEmailAsUsername')){   
         my $username = $form->process("authWebGUI.username");
         $vars->{'create.form.username'} 
-            = WebGUI::Form::text($self->session, {
+            = WebGUI::Form::username($self->session, {
                 name   => "authWebGUI.username",
                 value  => $username,
                 extras => $self->getExtrasStyle($username)
@@ -326,6 +327,18 @@ sub deactivateAccountConfirm {
     return $self->displayLogin(sprintf( $i18n->get("deactivateAccount success"), $username ));
 }
 
+#-------------------------------------------------------------------
+
+=head2 checkField ( )
+
+Performs AJAX checks on form field input. For example, can check whether a user
+name is free for registration.
+
+Returns the JSON {"error":"errorString"} where errorString is an error message
+or an empty string if the check was successful.
+
+=cut
+
 #-------------------------------------------------------------------
 sub displayAccount {
    my $self = shift;
@@ -387,7 +400,8 @@ sub editUserForm {
    $f->password(
 	name=>"authWebGUI.identifier",
 	label=>$i18n->get(51),
-	value=>"password"
+	value=>"password",
+    extras=>'autocomplete="off"',
 	);
    $f->interval(
 	-name=>"authWebGUI.passwordTimeout",
@@ -597,6 +611,13 @@ sub editUserSettingsForm {
 		-label     => $i18n->get("password recovery template"),
 		-hoverHelp => $i18n->get("password recovery template help")
     );
+    $f->template(
+        -name      => "webguiPasswordRecoveryEmailTemplate",
+        -value     => $self->session->setting->get('webguiPasswordRecoveryEmailTemplate'),
+        -label     => $i18n->get('Password Recovery Email Template'),
+		-hoverHelp => $i18n->get("password recovery email template help"),
+		-namespace => "Auth/WebGUI/RecoveryEmail",
+    );
     $f->template(
         -name      => "webguiWelcomeMessageTemplate",
         -value     => $self->session->setting->get("webguiWelcomeMessageTemplate"),
@@ -666,6 +687,8 @@ sub editUserSettingsFormSave {
 	$s->set("webguiPasswordRecoveryTemplate",        $f->process("webguiPasswordRecoveryTemplate","template"));
     $s->set("webguiWelcomeMessageTemplate",          $f->process("webguiWelcomeMessageTemplate","template"));
     $s->set("webguiAccountActivationTemplate",       $f->process("webguiAccountActivationTemplate","template")); 
+	$s->set("webguiPasswordRecoveryTemplate",        $f->process("webguiPasswordRecoveryTemplate","template"));
+	$s->set("webguiPasswordRecoveryEmailTemplate",   $f->process("webguiPasswordRecoveryEmailTemplate","template"));
 
     if (@errors) {
         return \@errors;
@@ -1090,7 +1113,6 @@ sub emailRecoverPasswordFinish {
 
     # generate information necessry to proceed
     my $recoveryGuid = $session->id->generate();
-    my $url = $session->url->getSiteURL;
     my $userId = $user->userId; #get the user guid
     $email = $user->profileField('email');
 
@@ -1104,7 +1126,12 @@ sub emailRecoverPasswordFinish {
     $self->saveParams($userId, 'WebGUI', $authsettings);
 
     my $mail = WebGUI::Mail::Send->create($session, { to=>$email, subject=>$i18n->get('WebGUI password recovery')});
-    $mail->addText($i18n->get('recover password email text1', 'AuthWebGUI') . $url. ". \n\n".$i18n->get('recover password email text2', 'AuthWebGUI')." \n\n ".$url."?op=auth;method=emailResetPassword;token=$recoveryGuid"."\n\n ". $i18n->get('recover password email text3', 'AuthWebGUI'));
+    my $vars = { };
+    $vars->{recoverPasswordUrl} = $session->url->append($session->url->getSiteURL,'op=auth;method=emailResetPassword;token='.$recoveryGuid);
+    my $template  = WebGUI::Asset->newByDynamicClass($session, $session->setting->get('webguiPasswordRecoveryEmailTemplate'));
+    my $emailText = $template->process($vars);
+    WebGUI::Macro::process($session, \$emailText);
+    $mail->addText($emailText);
     $mail->queue;
     return "<h1>". $i18n->get('recover password banner', 'AuthWebGUI')." </h1> <br> <br> <h3>". $i18n->get('email recover password finish message', 'AuthWebGUI') . "</h3>";
 }
