@@ -372,9 +372,6 @@ sub www_manage {
     $session->style->setScript( $session->url->extras( 'yui-webgui/build/form/form.js' ) );
 
     $session->style->setRawHeadTags( <<ENDHTML );
-    <link type="text/css" rel="stylesheet" href="http://yui.yahooapis.com/2.6.0/build/logger/assets/skins/sam/logger.css">
-    <script type="text/javascript" src="http://yui.yahooapis.com/2.6.0/build/logger/logger-min.js"></script> 
-
     <script type="text/javascript">
         YAHOO.util.Event.onDOMReady( WebGUI.AssetManager.initManager );
     </script>
@@ -383,13 +380,20 @@ ENDHTML
 
     ### Crumbtrail
     my $crumb_markup    = '<li><a href="%s">%s</a> &gt;</li>';
-    my $ancestors       = $currentAsset->getLineage( ['ancestors'], { returnObjects => 1 } );
+    my $ancestorIter    = $currentAsset->getLineageIterator( ['ancestors'] );
 
     $output             .=  '<ol id="crumbtrail">';
-    for my $asset ( @{ $ancestors } ) {
+    while ( 1 ) {
+        my $ancestor;
+        eval { $ancestor = $ancestorIter->() };
+        if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+            $session->log->error($x->full_message);
+            next;
+        }
+        last unless $ancestor;
         $output .= sprintf $crumb_markup, 
-                $asset->getUrl( 'op=assetManager;method=manage' ),
-                $asset->get( "menuTitle" ),
+                $ancestor->getUrl( 'op=assetManager;method=manage' ),
+                $ancestor->get( "menuTitle" ),
                 ;
     }
 
@@ -475,6 +479,8 @@ EOHTML
         . WebGUI::Form::hidden($session, {name=>"func", value=>"importPackage"})
         . '<div><input type="file" name="packageFile" size="30" style="font-size: 10px;" /></div>'
         . '<div style="font-size: 10px">'
+        . WebGUI::Form::checkbox($session, { label => $i18n->get('clear package flag'), checked => 0, name => 'clearPackageFlag', value => 1 })
+        . '<br />'
         . WebGUI::Form::checkbox($session, { label => $i18n->get('inherit parent permissions'), checked => 1, name => 'inheritPermissions', value => 1 })
         . ' &nbsp; ' .  WebGUI::Form::submit($session, { value=>$i18n->get("import"), 'extras' => ' ' })
         . '</div>'
