@@ -116,18 +116,18 @@ sub getCountries {
         'Cayman Islands',                        'Central African Republic',
         'Chad',                                  'Chile',
         'China',                                 'Christmas Island',
-        'Cocos (Keeling) Islands',               'Colombia',
-        'Comoros',                               'Congo',
-        'Congo, the Democratic Republic of the', 'Cook Islands',
-        'Costa Rica',                            'Cote d\'Ivoire',
-        'Croatia',                               'Cyprus',
-        'Czech Republic',                        'Denmark',
-        'Djibouti',                              'Dominica',
-        'Dominican Republic',                    'East Timor',
-        'Ecuador',                               'Egypt',
-        'El Salvador',                           'England',
-        'Equatorial Guinea',                     'Eritrea',
-        'Espana',                                'Estonia',
+        'Christmas Island (Kiribati)',           'Cocos (Keeling) Islands',
+        'Colombia',                              'Comoros',
+        'Congo',                                 'Congo, the Democratic Republic of the',
+        'Cook Islands',                          'Costa Rica',
+        'Cote d\'Ivoire',                        'Croatia',
+        'Cyprus',                                'Czech Republic',
+        'Denmark',                               'Djibouti',
+        'Dominica',                              'Dominican Republic',
+        'East Timor',                            'Ecuador',
+        'Egypt',                                 'El Salvador',
+        'England',                               'Equatorial Guinea',
+        'Eritrea',                               'Estonia',
         'Ethiopia',                              'Falkland Islands',
         'Faroe Islands',                         'Fiji',
         'Finland',                               'France',
