@@ -21,6 +21,7 @@ use WebGUI::Macro;
 use WebGUI::Utility;
 use WebGUI::Pluggable;
 use WebGUI::International;
+use Scalar::Util qw( weaken );
 
 
 =head1 NAME
@@ -1520,6 +1521,7 @@ sub new {
     
     my $class           = shift;
     $self->{_session}   = shift;
+    weaken( $self->{_session} );
 	$self->{_groupId}   = shift;
 	my $override        = shift;
     my $noAdmin         = shift;
@@ -1590,13 +1592,12 @@ sub resetGroupFields {
     my $session = $self->session;
     my $db      = $session->db;
     my $config  = $session->config;
-    my $assets  = $config->get('assets');
     my $tableCache = {};
 
     ##Note, I did assets in SQL instead of using the API because you would have to
     ##instanciate every version of the asset that used the group.  This should be much quicker
-    ASSET: foreach my $asset (keys %{ $assets }) {
-        my $definition = WebGUI::Pluggable::instanciate($asset, 'definition', [$session]);
+    ASSET: foreach my $assetClass ($db->buildArray('SELECT DISTINCT className FROM asset')) {
+        my $definition = WebGUI::Pluggable::instanciate($assetClass, 'definition', [$session]);
         SUBDEF: foreach my $subdef (@{ $definition }) {
             next SUBDEF if exists $tableCache->{$subdef->{tableName}}; 
             PROP: while (my ($fieldName, $properties) = each %{ $subdef->{properties} }) {
@@ -1992,7 +1993,7 @@ sub vitalGroup {
     if (! $groupId && ref $class ) {
         $groupId = $class->getId;
     }
-    return isIn ( $groupId, (1..17), qw/pbgroup000000000000015 pbgroup000000000000016 pbgroup000000000000017 / );
+    return isIn ( $groupId, (1..13), 15,16,17, qw/pbgroup000000000000015 pbgroup000000000000016 pbgroup000000000000017 / );
 }
 
 1;
