@@ -15,6 +15,7 @@ package WebGUI::Session;
 =cut
 
 use strict;
+use Scalar::Util qw( weaken );
 use WebGUI::Config;
 use WebGUI::SQL;
 use WebGUI::User;
@@ -109,6 +110,19 @@ sub asset {
 
 #-------------------------------------------------------------------
 
+=head2 clearAsset ( )
+
+Clears out the session asset.
+
+=cut
+
+sub clearAsset {
+    my $self        = shift;
+    $self->{_asset} = undef;
+}
+
+#-------------------------------------------------------------------
+
 =head2 close
 
 Cleans up a WebGUI session information from memory and disconnects from any resources opened by the session.
@@ -121,7 +135,8 @@ sub close {
 
 	# Kill circular references.  The literal list is so that the order
 	# can be explicitly shuffled as necessary.
-	foreach my $key (qw/_asset _datetime _icon _slave _db _env _form _http _id _output _os _privilege _scratch _setting _stow _style _url _user _var _errorHandler/) {
+        # XXX Is this necessary when we have weakened session refs?
+	foreach my $key (qw/_asset _datetime _icon _slave _db _env _form _http _id _output _os _privilege _scratch _setting _stow _style _url _user _var _errorHandler /) {
 		delete $self->{$key};
 	}
 }
