@@ -16,6 +16,7 @@ package WebGUI::Session::Icon;
 
 use strict;
 use WebGUI::International;
+use Scalar::Util qw( weaken );
 
 
 =head1 NAME
@@ -86,7 +87,8 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
 
 =cut
 
@@ -112,7 +114,8 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
 
 =cut
 
@@ -152,7 +155,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =head3 confirmText 
 
@@ -205,7 +210,8 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
 
 =cut
 
@@ -231,7 +237,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -282,7 +290,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -308,7 +318,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -334,7 +346,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -360,7 +374,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =head3 disabled
 
@@ -394,7 +410,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -420,7 +438,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -446,7 +466,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -472,7 +494,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =head3 disabled
 
@@ -510,7 +534,9 @@ A reference to the current session.
 sub new {
 	my $class = shift;
 	my $session = shift;
-	bless {_session=>$session}, $class;
+	my $self = bless {_session=>$session}, $class;
+        weaken( $self->{_session} );
+        return $self;
 }
 
 
@@ -540,7 +566,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -566,7 +594,9 @@ Any URL parameters that need to be tacked on to the current URL to accomplish wh
 
 =head3 pageURL
 
-The URL to any page. Defaults to the current page.
+The URL to any page. Defaults to the current page.  If a URL is passed, the gateway URL from the site's config
+file will be prepended to it.
+
 
 =cut
 
@@ -581,6 +611,4 @@ sub view {
 }
 
 
-
 1;
-
