@@ -23,9 +23,11 @@ use WebGUI::Utility;
 use WebGUI::Operation::Shared;
 use WebGUI::Workflow::Instance;
 use WebGUI::Shop::AddressBook;
+use WebGUI::Shop::Credit;
 use JSON;
 use WebGUI::Exception;
 use WebGUI::ProfileField;
+use Scalar::Util qw( weaken );
 
 =head1 NAME
 
@@ -423,6 +425,9 @@ sub delete {
         $book->delete;
     }
 
+    my $credit = WebGUI::Shop::Credit->new($session, $userId);
+    $credit->purge;
+
     # remove user itself
     $db->write("DELETE FROM userProfileData WHERE userId=?",[$userId]);
     $db->write("DELETE FROM users WHERE userId=?",[$userId]);
@@ -774,7 +779,7 @@ Field to get privacy setting for.
 sub getProfileFieldPrivacySetting {
     my $self      = shift;
     my $session   = $self->session;
-    my $field     = shift;
+    my $fieldId   = shift;
 
     unless ($self->{_privacySettings}) {
         #Look it up manually because we want to cache this separately.
@@ -786,12 +791,16 @@ sub getProfileFieldPrivacySetting {
         $self->{_privacySettings} = JSON->new->decode($privacySettings);
     }
     
-    return $self->{_privacySettings} unless ($field);
+    return $self->{_privacySettings} unless ($fieldId);
 
     #No privacy settings returned the privacy setting field
-    return "none" if($field eq "wg_privacySettings");
+    return "none" if($fieldId eq "wg_privacySettings");
 
-    return $self->{_privacySettings}->{$field};
+    if (exists $self->{_privacySettings}->{$fieldId}) {
+        return $self->{_privacySettings}->{$fieldId};
+    }
+    my $field = WebGUI::ProfileField->new($session, $fieldId);
+    return $field && $field->get('defaultPrivacySetting');
 }   
 
 
@@ -1077,6 +1086,7 @@ sub new {
     my $self        = $cache->get || {};
     bless $self, $class;
     $self->{_session} = $session;
+    weaken( $self->{_session} );
     unless ($self->{_userId} && $self->{_user}{username}) {
         my %user;
         tie %user, 'Tie::CPHash';
