@@ -186,6 +186,64 @@ sub commit {
 	return 2;
 }
 
+#-------------------------------------------------------------------
+
+=head2 commitAsUser ( userId , options )
+
+Commits the working tab.  If userId is passed in, commit will be done as that user
+
+=head3 userId
+
+User to commit tag as
+
+=head3 options
+
+hash ref of options to pass in
+
+=head4 comments
+
+optional comments to set in the version tag
+
+=head4 commitNow
+
+optional boolean which, if set, will perform an immediate.
+
+=cut
+
+sub commitAsUser {
+    my $self        = shift;
+    my $session     = $self->session;
+    my $config      = $session->config;
+    my $userId      = shift;
+    my $options     = shift;
+    my $commitNow   = $options->{commitNow};
+    my $comments    = $options->{comments};
+
+    return 0 unless (defined $userId);
+
+    #Open a new session
+    my $new_session = WebGUI::Session->open( $config->getWebguiRoot, $config->getFilename );
+    #Set the userId in the new session
+    $new_session->user( { userId => $userId } );
+
+    #Clone the tag into a new version tag in the new session
+    my $new_tag = __PACKAGE__->new( $new_session, $self->getId );
+    
+    if ( defined $new_tag ) {
+        $new_tag->set( { comments => $comments } );
+        if ($commitNow) {
+            $new_tag->commit;
+        }
+        else {
+            $new_tag->requestCommit;
+        }
+    }
+    #End the new session
+    $new_session->var->end;
+    $new_session->close;
+    return 1;
+}
+
 
 #-------------------------------------------------------------------
 
@@ -438,15 +496,15 @@ sub getWorking {
     #First see if there is already a version tag
     $tag = $stow->get(q{versionTag});
 
-    return $tag if $tag;
+    return $tag if ($tag && !$tag->isLocked);
 
     $tagId = $session->scratch()->get(q{versionTag});
     if ($tagId) {
         $tag = $class->new($session, $tagId);
-
-        $stow->set(q{versionTag}, $tag);
-
-        return $tag;
+        unless ($tag->isLocked) {
+            $stow->set(q{versionTag}, $tag);
+            return $tag;
+        }
     }
 
     #No tag found. Create or reclaim one?
@@ -475,10 +533,10 @@ sub getWorking {
         # For now, we only reclaim if 1 tag open.
         if (scalar @openTags == 1) {
             $tag = $openTags[0];
-
-            $tag->setWorking();
-
-            return $tag;
+            unless ($tag->isLocked) {
+                $tag->setWorking();
+                return $tag;
+            }
         }
     }
     elsif ($mode eq q{siteWide}) {
@@ -486,7 +544,7 @@ sub getWorking {
 
       OPENTAG:
         foreach my $openTag (@{WebGUI::VersionTag->getOpenTags($session)}) {
-            if ($openTag->get(q{isSiteWide})) {
+            if ($openTag->get(q{isSiteWide}) && !$openTag->isLocked) {
 
                 $tag = $openTag;
 
@@ -515,6 +573,16 @@ sub getWorking {
 
 #-------------------------------------------------------------------
 
+=head2 isLocked ( )
+
+Returns boolean value indicating whether tag is locked
+
+=cut
+
+sub isLocked { $_[0]{_data}{isLocked} }
+
+#-------------------------------------------------------------------
+
 =head2 leaveTag ( )
 
 Make the user leave their current tag.
@@ -738,6 +806,7 @@ Sets this tag as the working tag for the current user.
 
 sub setWorking {
 	my $self = shift;
+	return if $self->isLocked;
 	$self->session->scratch->set("versionTag",$self->getId);
 	$self->session->stow->set("versionTag", $self);
 }
