@@ -584,14 +584,12 @@ you wish to appear, one per line. <br />
 <br />If you want a different label for a value, the possible values list has to be
 formatted as follows:
 <pre>
-&#123;
-   "key1"=>"value1",
-   "key2"=>"value2",
-   "key3"=>"value3"
+   key1|value1
+   key2|value2
+   key3|value3
    ...
-&#125;
 </pre>
-Braces, quotes and all.  You simply replace "key1"/"value1" with your own name/value pairs},
+Simply replace "key1"/"value1" with your own name/value pairs},
         lastUpdated => 1223372150,
     },
 
@@ -972,11 +970,17 @@ search has been done.|,
     },
 
     'searchFields_is__fieldType__' => {
-        message => q|A boolean indicating wether this field is of type __fieldType__. The first letter of __fieldType__ is always uppercase. Example: for a select box the value of &lt;tmpl_var searchFields_isSelectBox&gt; is true.|,
+        message => q|A boolean indicating whether this field is of type __fieldType__. The first letter of __fieldType__ is always uppercase. Example: for a select box the value of &lt;tmpl_var searchFields_isSelectBox&gt; is true.|,
         lastUpdated => 1104630516,
         context => q|Description of a tmpl_var for the template help.|,
     },
 
+    'searchFields_listType' => {
+        message => q|A boolean indicating whether this field is a List type field.|,
+        lastUpdated => 1277849256,
+        context => q|Description of a tmpl_var for the template help.|,
+    },
+
     'displayInSearchFields_loop' => {
         message => q|A loop containing the fields that are displayed in the search results.|,
         lastUpdated => 1104630516,
@@ -1117,6 +1121,24 @@ search has been done.|,
         lastUpdated => 1231180362,
     },
 
+    'Creating column headers' => {
+        message => q|Creating column headers.|,
+        lastUpdated => 1231180362,
+        context => q|Status message in the Export Thingy progress bar.|,
+    },
+
+    'Writing data' => {
+        message => q|Writing data.|,
+        lastUpdated => 1231180362,
+        context => q|Status message in the Export Thingy progress bar.|,
+    },
+
+    'Return to %s' => {
+        message => q|Return to %s.|,
+        lastUpdated => 1231180362,
+        context => q|Status message in the Export Thingy progress bar. %s is the name of the Thing that is being exported.|,
+    },
+
 };
 
 1;
