@@ -77,7 +77,7 @@ our $I18N = {
     },
 
     'payment methods' => {
-        message => q|Payment Methods.|,
+        message => q|Payment Methods|,
         lastUpdated => 1213313375,
         context => q|Help body for the email receipt template|,
     },
@@ -93,6 +93,31 @@ our $I18N = {
         lastUpdated => 0,
         context     => q{Link to begin checkout again after failure},
     },
+
+	'template gone' => {
+		message => q|The template for entering in credentials has been deleted.  Please notify the site administrator.|,
+		lastUpdated => 0,
+		context => q|Error message when a template cannot be accessed.|
+	},
+
+	'cart summary variables' => {
+		message => q|Cart Summary Variables|,
+		lastUpdated => 0,
+		context => q|Title for a template variable help page.|
+	},
+
+	'cart summary variables help' => {
+		message => q|These variables should be available in all PayDriver templates, to display the cart summary to the user.|,
+		lastUpdated => 0,
+		context => q|Body for a template variable help page.|
+	},
+
+    'proceedButton' => {
+        message => q|A combined button and form for the user to press when they have reviewed the charges that will be submitted to this payment gateway.|,
+        lastUpdated => 0,
+        context => q|Status message|,
+    },
+
 };
 
 1;
