@@ -217,6 +217,10 @@ our $I18N = {
     'lastUpdated' => '1273649880',
     'message' => 'Bitte geben Sie Bundesland/Bezirk für die Rechnungsadresse an.'
   },
+  'billingAddressChooser help' => {
+    'lastUpdated' => '1278344752',
+    'message' => 'Eine Dropdown-Auswahlliste zur Auswahl der Standardrechnungsadresse.'
+  },
   'biweekly' => {
     'lastUpdated' => '1228749149',
     'message' => 'Zwei Wochen'
@@ -397,6 +401,10 @@ our $I18N = {
     'lastUpdated' => '1228749164',
     'message' => 'E-Mail'
   },
+  'emailField help' => {
+    'lastUpdated' => '1278344792',
+    'message' => 'Ein Feld, das die E-Mail-Adresse zu dieser Adresse enthält.'
+  },
   'empty cart' => {
     'lastUpdated' => '1240755736',
     'message' => 'Ihr Warenkorb ist leer'
@@ -501,6 +509,10 @@ our $I18N = {
     'lastUpdated' => '1240756823',
     'message' => 'Die Asset-ID für diesen Artikel.'
   },
+  'item extendedPricePlusTax help' => {
+    'lastUpdated' => '1279222176',
+    'message' => 'Steuer plus Preis für diesen Artikel multipliziert mit seiner Menge im Warenkorb. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
+  },
   'item lastUpdated' => {
     'lastUpdated' => '1240781617',
     'message' => 'Datum letzter Änderung Transaktionsitem'
@@ -517,6 +529,10 @@ our $I18N = {
     'lastUpdated' => '1240755758',
     'message' => 'Artikelpreis'
   },
+  'item pricePlusTax help' => {
+    'lastUpdated' => '1279222216',
+    'message' => 'Steuer plus Preis für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
+  },
   'item quantity' => {
     'lastUpdated' => '1240758930',
     'message' => 'Artikelmenge'
@@ -565,6 +581,14 @@ our $I18N = {
     'lastUpdated' => '1241158116',
     'message' => 'Name Versandadresse für dieses Item'
   },
+  'item taxAmount help' => {
+    'lastUpdated' => '1279222235',
+    'message' => 'Steuer für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
+  },
+  'item taxRate help' => {
+    'lastUpdated' => '1279222254',
+    'message' => 'Steuersatz für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
+  },
   'item transactionId' => {
     'lastUpdated' => '1241157961',
     'message' => 'ID Transaktion'
@@ -577,6 +601,10 @@ our $I18N = {
     'lastUpdated' => '1241157332',
     'message' => 'Die ID des Verkäufers dieses Items'
   },
+  'itemAddressChooser help' => {
+    'lastUpdated' => '1278344908',
+    'message' => 'Eine Dropdown-Auswahlliste zur Wahl der Versandadresse eines einzelnen Produktes im Warenkorb, ermöglicht durch Pro-Produkt-Versand.'
+  },
   'itemId' => {
     'lastUpdated' => '1241158021',
     'message' => 'Die eindeutige ID für dieses Item aus allen Items in allen Transaktionen'
@@ -610,6 +638,26 @@ our $I18N = {
     'message' => 'Sie müssen sich <a href="%s">anmelden</a> um den Einkauf tätigen zu können.
 '
   },
+  'loginFormButton help' => {
+    'lastUpdated' => '1278535802',
+    'message' => 'Das Ende des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
+  },
+  'loginFormFooter help' => {
+    'lastUpdated' => '1278535775',
+    'message' => 'Das Ende des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
+  },
+  'loginFormHeader help' => {
+    'lastUpdated' => '1278535758',
+    'message' => 'Der Anfang des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
+  },
+  'loginFormPassword help' => {
+    'lastUpdated' => '1278535661',
+    'message' => 'Eine Textbox mit der die Benutzer ihr Passwort verdeckt eingeben. Die Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
+  },
+  'loginFormUsername help' => {
+    'lastUpdated' => '1278535599',
+    'message' => 'Eine Textbox mit der die Benutzer ihren Namen eingeben. Die Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
+  },
   'manage' => {
     'lastUpdated' => '1240758683',
     'message' => 'Verwalten'
@@ -622,6 +670,10 @@ our $I18N = {
     'lastUpdated' => '1241190631',
     'message' => 'DIese Vorlage zeigt Teilinformationen zu den Transaktionen des benutzers an.'
   },
+  'message help' => {
+    'lastUpdated' => '1278344956',
+    'message' => 'Wenn der Warenkorb leer ist wir dem Benutzer diese internationalisierte Meldung angezeigt.'
+  },
   'minicart template' => {
     'lastUpdated' => '1240781660',
     'message' => 'Warenkorb Vorlage'
@@ -630,6 +682,10 @@ our $I18N = {
     'lastUpdated' => '1241190295',
     'message' => 'Die folgenden Variablen sind in der Vorlage zum Warenkorb vorhanden.'
   },
+  'minimumCartAmount help' => {
+    'lastUpdated' => '1278345032',
+    'message' => 'Der minimale Warenkorbwert aus den Einstellungen mit formatiert mit zwei Nachkommastellen.'
+  },
   'mixed items warning' => {
     'lastUpdated' => '1241157671',
     'message' => 'Sie können leider keine Artikel mit und Artikel ohne Verlängerungsoption in Ihren Warenkorb aufnehmen und bezahlen.
@@ -781,6 +837,10 @@ Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste
     'lastUpdated' => '1241158419',
     'message' => 'Bundesland Rechnungsadresse'
   },
+  'paymentOptions help' => {
+    'lastUpdated' => '1278345421',
+    'message' => 'Eine Auswahlliste die alle konfigurierten Bezahlmöglichkeiten für diese Bestellung enthält.'
+  },
   'per item shipping' => {
     'lastUpdated' => '1241298477',
     'message' => 'Einzellieferung'
@@ -853,10 +913,18 @@ Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste
     'lastUpdated' => '1240758373',
     'message' => 'Rückerstattung'
   },
+  'registerLink help' => {
+    'lastUpdated' => '1278345370',
+    'message' => 'Ein Link, mit dem der Benutzer einen Account auf dieser Seite erstellen kann, falls er noch keinen hat. Diese Variable wird nur zur Verfügung gestellt, wenn der aktuelle Benutzer Besucher ist.'
+  },
   'remove button' => {
     'lastUpdated' => '1240758225',
     'message' => 'Entfernen'
   },
+  'removeBox help' => {
+    'lastUpdated' => '1278345292',
+    'message' => 'Eine Checkbox um diesen Artikel aus dem Warenkorb zu löschen.'
+  },
   'removeButton help' => {
     'lastUpdated' => '1241167089',
     'message' => 'Anklicken dieses Knopfs entfernt den Artikel aus dem Warenkorb.'
@@ -873,6 +941,10 @@ Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste
     'lastUpdated' => '1256112886',
     'message' => 'Wer soll über eine neue Transaktion benachrichtigt werden?'
   },
+  'sameShippingAsBilling help' => {
+    'lastUpdated' => '1278345265',
+    'message' => 'Eine Checkbox um dem Warenkorb identische Versand- und Rechnungsadresse zuzuweisen.'
+  },
   'saveButton help' => {
     'lastUpdated' => '1240758305',
     'message' => 'Der Standardtext zum Sichern-Knopf'
@@ -982,6 +1054,10 @@ Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste
     'lastUpdated' => '1240757994',
     'message' => 'Die dritte Zeile einer Versandadresse'
   },
+  'shippingAddressChooser help' => {
+    'lastUpdated' => '1278345182',
+    'message' => 'Eine Dropdown-Auswahlliste zur Auswahl einer Standardversandadresse für alle Artikel im Warenkorb. Möglichkeit zur Bearbeitung und Ergänzung von Adressen ist vorhanden.'
+  },
   'shippingAddressCity' => {
     'lastUpdated' => '1240756142',
     'message' => 'Ort'
@@ -1166,6 +1242,10 @@ Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste
     'lastUpdated' => '1228750362',
     'message' => 'Die Benutzer-ID des Benutzers, der diese Trransaktion ausgeführt hat.'
   },
+  'userIsVisitor help' => {
+    'lastUpdated' => '1278345076',
+    'message' => 'Ein boolscher Wert der wahr ist, falls der aktuelle Benutzer Besucher ist.'
+  },
   'username' => {
     'lastUpdated' => '1228749285',
     'message' => 'Benutzer'
