@@ -555,6 +555,10 @@ asociado.'
     'lastUpdated' => '1253308903',
     'message' => 'La etiquetda de un campo sobre el cual se puede buscar.'
   },
+  'searchFields_listType' => {
+    'lastUpdated' => '1280335612',
+    'message' => 'Un condicional que indica si el campo es de tipo Lista.'
+  },
   'searchFields_loop' => {
     'lastUpdated' => '1253308916',
     'message' => 'Un ciclo que contiene los campos sobre los cuales se puede buscar.'
