@@ -28,53 +28,65 @@ use base qw(Test::Builder::Module);
 
 use Test::MockObject;
 use Test::MockObject::Extends;
+use Log::Log4perl;  # load early to ensure proper order of END blocks
 use Clone               qw(clone);
-use Config              ();
+use File::Basename      qw(dirname fileparse);
+use File::Spec::Functions qw(abs2rel rel2abs catdir catfile updir);
 use IO::Handle          ();
-use File::Spec          ();
 use IO::Select          ();
 use Cwd                 ();
 use Scalar::Util        qw( blessed );
 use List::MoreUtils     qw( any );
 use Carp                qw( carp croak );
 use JSON                qw( from_json to_json );
+use Monkey::Patch       qw( patch_object );
 use Scope::Guard;
 
 BEGIN {
-    my $file_root = File::Spec->catpath((File::Spec->splitpath(__FILE__))[0,1], '');
 
-    our $WEBGUI_ROOT = Cwd::realpath( File::Spec->catdir( $file_root, (File::Spec->updir) x 3 ));
-    our $WEBGUI_TEST_COLLATERAL = File::Spec->catdir($WEBGUI_ROOT, 't', 'supporting_collateral');
-    our $WEBGUI_LIB = File::Spec->catdir( $WEBGUI_ROOT, 'lib' );
+our $WEBGUI_TEST_ROOT = File::Spec->catdir(
+    File::Spec->catpath((File::Spec->splitpath(__FILE__))[0,1], ''),
+    (File::Spec->updir) x 2
+);
+our $WEBGUI_TEST_COLLATERAL = File::Spec->catdir(
+    $WEBGUI_TEST_ROOT,
+    'supporting_collateral'
+);
+our $WEBGUI_ROOT = File::Spec->catdir(
+    $WEBGUI_TEST_ROOT,
+    File::Spec->updir,
+);
+our $WEBGUI_LIB = File::Spec->catdir(
+    $WEBGUI_ROOT,
+    'lib',
+);
 
-    push @INC, $WEBGUI_LIB;
+push @INC, $WEBGUI_LIB;
 
-    ##Handle custom loaded library paths
-    my $customPreload = File::Spec->catfile( $WEBGUI_ROOT, 'sbin', 'preload.custom');
-    if (-e $customPreload) {
-        open my $PRELOAD, '<', $customPreload or
-            croak "Unload to open $customPreload: $!\n";
-        LINE: while (my $line = <$PRELOAD>) {
-            $line =~ s/#.*//;
-            $line =~ s/^\s+//;
-            $line =~ s/\s+$//;
-            next LINE if !$line;
-            unshift @INC, $line;
-        }
-        close $PRELOAD;
+##Handle custom loaded library paths
+my $customPreload = File::Spec->catfile( $WEBGUI_ROOT, 'sbin', 'preload.custom');
+if (-e $customPreload) {
+    open my $PRELOAD, '<', $customPreload or
+        croak "Unload to open $customPreload: $!\n";
+    LINE: while (my $line = <$PRELOAD>) {
+        $line =~ s/#.*//;
+        $line =~ s/^\s+//;
+        $line =~ s/\s+$//;
+        next LINE if !$line;
+        unshift @INC, $line;
     }
+    close $PRELOAD;
+}
+
 }
 
-use WebGUI::Session;
 use WebGUI::PseudoRequest;
 
 our @EXPORT = qw(cleanupGuard addToCleanup);
-our @EXPORT_OK = qw(session config);
+our @EXPORT_OK = qw(session config collateral);
 
 my $CLASS = __PACKAGE__;
 
-my @guarded;
-
 sub import {
     our $CONFIG_FILE = $ENV{ WEBGUI_CONFIG };
 
@@ -87,11 +99,17 @@ sub import {
     die "WEBGUI_CONFIG path '$CONFIG_FILE' is not readable by effective uid '$>'.\n"
         unless -r _;
 
-    $CONFIG_FILE = File::Spec->abs2rel($CONFIG_FILE, File::Spec->catdir($CLASS->root, 'etc'));
+    my $etcDir = Cwd::realpath(File::Spec->catdir($CLASS->root, 'etc'));
+    $CONFIG_FILE = File::Spec->abs2rel($CONFIG_FILE, $etcDir);
+
+    goto &{ $_[0]->can('SUPER::import') };
+}
+
+sub _initSession {
     my $session = our $SESSION = $CLASS->newSession(1);
 
     my $originalSetting = clone $session->setting->get;
-    push @guarded, Scope::Guard->new(sub {
+    $CLASS->addToCleanup(sub {
         while (my ($param, $value) = each %{ $originalSetting }) {
             $session->setting->set($param, $value);
         }
@@ -110,18 +128,23 @@ sub import {
             Workflows           => 'Workflow',
             Carts               => 'cart',
             Transactions        => 'transaction',
+            AdSpaces            => 'adSpace',
+            Ads                 => 'advertisement',
+            Inbox               => 'inbox',
             'Transaction Items' => 'transactionItem',
+            'Address Books'     => 'addressBook',
             'Ship Drivers'      => 'shipper',
             'Payment Drivers'   => 'paymentGateway',
             'Database Links'    => 'databaseLink',
             'LDAP Links'        => 'ldapLink',
+            'Profile Fields'    => 'userProfileField',
         );
         my %initCounts;
         for ( my $i = 0; $i < @checkCount; $i += 2) {
             my ($label, $table) = @checkCount[$i, $i+1];
             $initCounts{$table} = $session->db->quickScalar('SELECT COUNT(*) FROM ' . $table);
         }
-        push @guarded, Scope::Guard->new(sub {
+        $CLASS->addToCleanup(sub {
             for ( my $i = 0; $i < @checkCount; $i += 2) {
                 my ($label, $table) = @checkCount[$i, $i+1];
                 my $quant = $session->db->quickScalar('SELECT COUNT(*) FROM ' . $table);
@@ -132,27 +155,12 @@ sub import {
             }
         });
     }
-
-    goto &{ $_[0]->can('SUPER::import') };
 }
 
 END {
     $CLASS->cleanup;
 }
 
-sub cleanup {
-    # remove guards in reverse order they were added, triggering all of the
-    # requested cleanup operations
-    pop @guarded
-        while @guarded;
-
-    if ( our $SESSION ) {
-        $SESSION->var->end;
-        $SESSION->close;
-        undef $SESSION;
-    }
-}
-
 #----------------------------------------------------------------------------
 
 =head2 newSession ( $noCleanup )
@@ -166,12 +174,15 @@ If true, the session won't be registered for automatic deletion.
 =cut
 
 sub newSession {
+    shift
+        if eval { $_[0]->isa($CLASS) };
     my $noCleanup = shift;
     my $pseudoRequest = WebGUI::PseudoRequest->new;
+    require WebGUI::Session;
     my $session = WebGUI::Session->open( $CLASS->root, $CLASS->file );
     $session->{_request} = $pseudoRequest;
     if ( ! $noCleanup ) {
-        $CLASS->sessionsToDelete($session);
+        $CLASS->addToCleanup($session);
     }
     return $session;
 }
@@ -306,6 +317,9 @@ sub interceptLogging {
     $logger->mock( 'error',    sub { our $logger_error = $_[1]} );
     $logger->mock( 'isDebug',  sub { return 1 } );
     $logger->mock( 'is_debug', sub { return 1 } );
+    $logger->mock( 'is_info',  sub { return 1 } );
+    $logger->mock( 'is_warn',  sub { return 1 } );
+    $logger->mock( 'is_error', sub { return 1 } );
 }
 
 #----------------------------------------------------------------------------
@@ -324,7 +338,10 @@ sub restoreLogging {
            ->unmock( 'info'     )
            ->unmock( 'error'    )
            ->unmock( 'isDebug'  )
-           ->unmock( 'is_debug' );
+           ->unmock( 'is_debug' )
+           ->unmock( 'is_info'  )
+           ->unmock( 'is_warn'  )
+           ->unmock( 'is_error' );
 }
 
 #----------------------------------------------------------------------------
@@ -335,9 +352,13 @@ Returns the config object from the session.
 
 =cut
 
+my $config;
 sub config {
-    return undef unless defined $CLASS->session;
-    return $CLASS->session->config;
+    return $config
+        if $config;
+    require WebGUI::Config;
+    $config = WebGUI::Config->new($CLASS->root, $CLASS->file, 1);
+    return $config;
 }
 
 #----------------------------------------------------------------------------
@@ -437,8 +458,12 @@ Optionally adds a filename to the end.
 
 sub getTestCollateralPath {
     my $class           = shift;
-    my $filename        = shift;
-    return File::Spec->catfile(our $WEBGUI_TEST_COLLATERAL, $filename);
+    my @path            = @_;
+    return File::Spec->catfile(our $WEBGUI_TEST_COLLATERAL, @path);
+}
+
+sub collateral {
+    return $CLASS->getTestCollateralPath(@_);
 }
 
 #----------------------------------------------------------------------------
@@ -481,7 +506,11 @@ disabled.
 =cut
 
 sub session {
-    return our $SESSION;
+    our $SESSION;
+    if (! $SESSION) {
+        _initSession();
+    }
+    return $SESSION;
 }
 
 #----------------------------------------------------------------------------
@@ -554,7 +583,7 @@ sub prepareMailServer {
     # Let it start up yo
     sleep 2;
 
-    push @guarded, Scope::Guard->new(sub {
+    $CLASS->addToCleanup(sub {
         # Close SMTPD
         if ($smtpdPid) {
             kill INT => $smtpdPid;
@@ -587,7 +616,7 @@ sub originalConfig {
     }
     # add cleanup handler if this is the first time we were run
     if (! keys %originalConfig) {
-        push @guarded, Scope::Guard->new(sub {
+        $class->addToCleanup(sub {
             while (my ($key, $value) = each %originalConfig) {
                 if (defined $value) {
                     $CLASS->session->config->set($key, $value);
@@ -603,7 +632,7 @@ sub originalConfig {
 
 #----------------------------------------------------------------------------
 
-=head2 getMail ( ) 
+=head2 getMail ( )
 
 Read a sent mail from the prepared mail server (L<prepareMailServer>)
 
@@ -611,7 +640,7 @@ Read a sent mail from the prepared mail server (L<prepareMailServer>)
 
 sub getMail {
     my $json;
-    
+
     if ( !$smtpdSelect ) {
         return from_json ' { "error": "mail server not prepared" }';
     }
@@ -622,11 +651,11 @@ sub getMail {
     else {
         $json = ' { "error": "mail not sent" } ';
     }
-    
+
     if (!$json) {
         $json = ' { "error": "error in getting mail" } ';
     }
-    
+
     return from_json( $json );
 }
 
@@ -646,7 +675,7 @@ sub getMailFromQueue {
     if ( !$smtpdSelect ) {
         $class->prepareMailServer;
     }
-    
+
     my $messageId = $CLASS->session->db->quickScalar( "SELECT messageId FROM mailQueue" );
     warn $messageId;
     return unless $messageId; 
@@ -657,26 +686,28 @@ sub getMailFromQueue {
 
     return $class->getMail;
 }
+
 #----------------------------------------------------------------------------
 
-=head2 sessionsToDelete ( $session, [$session, ...] )
+=head2 overrideSetting (name, val)
 
-Push a list of session objects onto the stack of groups to be automatically deleted
-at the end of the test.  Note, this will be the last group of objects to be
-cleaned up.
-
-This is a class method.
+Overrides WebGUI::Test->session->setting->get($name) to return $val until the
+handle this method returns goes out of scope.
 
 =cut
 
-sub sessionsToDelete {
-    my $class = shift;
-    push @guarded, cleanupGuard(@_);
+sub overrideSetting {
+    my ($class, $name, $val) = @_;
+    patch_object $class->session->setting => get => sub {
+        my $get = shift;
+        return $val if $_[1] eq $name;
+        goto &$get;
+    };
 }
 
 #----------------------------------------------------------------------------
 
-=head2 assetsToPurge ( $asset, [$asset ] )
+=head2 cleanupAdminInbox ( )
 
 Push a list of Asset objects onto the stack of assets to be automatically purged
 at the end of the test.  This will also clean-up all version tags associated
@@ -686,94 +717,13 @@ This is a class method.
 
 =cut
 
-sub assetsToPurge {
+sub cleanupAdminInbox {
     my $class = shift;
-    push @guarded, cleanupGuard(@_);
+    my $admin = WebGUI::User->new($class->session, '3');
+    my $inbox = WebGUI::Inbox->new($class->session);
+    $inbox->deleteMessagesForUser($admin);
 }
 
-#----------------------------------------------------------------------------
-
-=head2 groupsToDelete ( $group, [$group ] )
-
-Push a list of group objects onto the stack of groups to be automatically deleted
-at the end of the test.
-
-This is a class method.
-
-=cut
-
-sub groupsToDelete {
-    my $class = shift;
-    push @guarded, cleanupGuard(@_);
-}
-
-
-#----------------------------------------------------------------------------
-
-=head2 storagesToDelete ( $storage, [$storageId ] )
-
-Push a list of storage objects or storageIds onto the stack of storage locaitons
-at the end of the test.
-
-This is a class method.
-
-=cut
-
-sub storagesToDelete {
-    my $class = shift;
-    push @guarded, cleanupGuard(map {
-        ref $_ ? $_ : ('WebGUI::Storage' => $_)
-    } @_);
-}
-
-#----------------------------------------------------------------------------
-
-=head2 tagsToRollback ( $tag )
-
-Push a list of version tags to rollback at the end of the test.
-
-This is a class method.
-
-=cut
-
-sub tagsToRollback {
-    my $class = shift;
-    push @guarded, cleanupGuard(@_);
-}
-
-#----------------------------------------------------------------------------
-
-=head2 usersToDelete ( $user, [$user, ...] )
-
-Push a list of user objects onto the stack of groups to be automatically deleted
-at the end of the test.  If found in the stack, the Admin and Visitor users will not be deleted.
-
-This is a class method.
-
-=cut
-
-sub usersToDelete {
-    my $class = shift;
-    push @guarded, cleanupGuard(@_);
-}
-
-#----------------------------------------------------------------------------
-
-=head2 workflowsToDelete ( $workflow, [$workflow, ...] )
-
-Push a list of workflow objects onto the stack of groups to be automatically deleted
-at the end of the test.
-
-This is a class method.
-
-=cut
-
-sub workflowsToDelete {
-    my $class = shift;
-    push @guarded, cleanupGuard(@_);
-}
-
-
 #----------------------------------------------------------------------------
 
 =head2 cleanupGuard ( $object, $class => $ident )
@@ -784,6 +734,7 @@ object goes out of scope, it will automatically clean up all of the
 passed in objects.  Objects will be destroyed in the order they
 were passed in.  Currently able to destroy:
 
+    WebGUI::AdSpace
     WebGUI::Asset
     WebGUI::Group
     WebGUI::Session
@@ -795,9 +746,12 @@ were passed in.  Currently able to destroy:
     WebGUI::Shop::ShipDriver
     WebGUI::Shop::PayDriver
     WebGUI::Shop::Transaction
+    WebGUI::Shop::Vendor
+    WebGUI::Shop::AddressBook
     WebGUI::DatabaseLink
     WebGUI::LDAPLink
     WebGUI::Inbox::Message
+    WebGUI::ProfileField
 
 Example call:
 
@@ -816,13 +770,24 @@ Example call:
             my ($class, $ident) = @_;
             return $class->new($CLASS->session, $ident);
         },
+        'WebGUI::Asset' => sub {
+            my ($class, $ident) = @_;
+            return WebGUI::Asset->newPending($CLASS->session, $ident);
+        },
         'WebGUI::Storage' => sub {
             my ($class, $ident) = @_;
             return WebGUI::Storage->get($CLASS->session, $ident);
         },
         'SQL' => sub {
             my (undef, $sql) = @_;
-            return $CLASS->session->db->dbh->prepare($sql);
+            my $db = $CLASS->session->db;
+            my @params;
+            if ( ref $sql ) {
+                ( $sql, @params ) = @$sql;
+            }
+            return sub {
+                $db->write( $sql, \@params );
+            }
         },
     );
 
@@ -875,23 +840,32 @@ Example call:
     );
 
     my %cleanup = (
-        'WebGUI::User'              => 'delete',
-        'WebGUI::Group'             => 'delete',
-        'WebGUI::Storage'           => 'delete',
-        'WebGUI::Asset'             => 'purge',
-        'WebGUI::VersionTag'        => 'rollback',
-        'WebGUI::Workflow'          => 'delete',
-        'WebGUI::DatabaseLink'      => 'delete',
-        'WebGUI::Shop::Transaction' => 'delete',
-        'WebGUI::Shop::ShipDriver'  => 'delete',
-        'WebGUI::Shop::PayDriver'   => 'delete',
+        'WebGUI::User'               => 'delete',
+        'WebGUI::Group'              => 'delete',
+        'WebGUI::Storage'            => 'delete',
+        'WebGUI::Asset'              => 'purge',
+        'WebGUI::VersionTag'         => 'rollback',
+        'WebGUI::Workflow'           => 'delete',
+        'WebGUI::DatabaseLink'       => 'delete',
+        'WebGUI::Shop::AddressBook'  => 'delete',
+        'WebGUI::Shop::Transaction'  => 'delete',
+        'WebGUI::Shop::ShipDriver'   => 'delete',
+        'WebGUI::Shop::PayDriver'    => 'delete',
+        'WebGUI::Shop::Vendor'       => 'delete',
         'WebGUI::Inbox::Message'     => 'purge',
-        'WebGUI::Shop::Cart'        => sub {
+        'WebGUI::AdSpace'            => 'delete',
+        'WebGUI::FilePump::Bundle'   => 'delete',
+        'WebGUI::ProfileField'       => 'delete',
+        'WebGUI::Shop::Cart'         => sub {
             my $cart        = shift;
-            my $addressBook = $cart->getAddressBook();
+            my $addressBook = eval { $cart->getAddressBook(); };
             $addressBook->delete if $addressBook;  ##Should we call cleanupGuard instead???
             $cart->delete;
         },
+        'WebGUI::Workflow::Instance' => sub {
+            my $instance = shift;
+            $instance->delete('skipNotify');
+        },
         'WebGUI::Session'          => sub {
             my $session = shift;
             $session->var->end;
@@ -904,7 +878,9 @@ Example call:
         'CODE' => sub {
             (shift)->();
         },
-        'SQL' => 'execute',
+        'SQL' => sub {
+            (shift)->();
+        },
     );
 
     sub cleanupGuard {
@@ -986,12 +962,32 @@ This is a class method.
 
 =cut
 
+my @guarded;
 sub addToCleanup {
     shift
         if eval { $_[0]->isa($CLASS) };
     push @guarded, cleanupGuard(@_);
 }
 
+sub cleanup {
+    if ($ENV{WEBGUI_TEST_NOCLEANUP}) {
+        (pop @guarded)->dismiss
+            while @guarded;
+        return;
+    }
+
+    # remove guards in reverse order they were added, triggering all of the
+    # requested cleanup operations
+    pop @guarded
+        while @guarded;
+
+    if ( our $SESSION ) {
+        $SESSION->var->end;
+        $SESSION->close;
+        undef $SESSION;
+    }
+}
+
 #----------------------------------------------------------------------------
 
 =head1 BUGS
